autowisp.processing_steps.stack_to_master module — AutoWISP documentation

# autowisp.processing_steps.stack_to_master module

## Class Inheritance Diagram

Stack a collection of images to a master frame.

class autowisp.processing_steps.stack_to_master.ParseAverageAction(option_strings, dest, nargs=None, const=None, default=None, type=None, choices=None, required=False, help=None, metavar=None)

  Bases: `Action`

  Parse the specification of the averaging function on the command line.

  __call__(parser, namespace, values, option_string=None)

    Set the callable to use for averaging.

autowisp.processing_steps.stack_to_master.cleanup_interrupted(interrupted, configuration)

  Cleanup file system after partially creating stacked image(s).

autowisp.processing_steps.stack_to_master.get_command_line_parser(*args, default_threshold=(5.0,), single_master=True, default_min_valid_values=5, default_max_iter=20)

  Return a command line parser with all arguments added.

autowisp.processing_steps.stack_to_master.get_master_fname(image_fname, configuration, fname_key='stacked_master_fname')

  Return the name of the master the given image should contribute to.

autowisp.processing_steps.stack_to_master.main()

  Run the step from the command line.

autowisp.processing_steps.stack_to_master.parse_command_line(*args)

  Return the parsed command line arguments.

autowisp.processing_steps.stack_to_master.stack_to_master(image_collection, start_status, configuration, mark_start, mark_end)

  Stack the given frames to produce a single master frame.